#
# spec file for package gitea-tea
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gitea-tea
Version:        0.10.1
Release:        1.1
Summary:        A command line tool to interact with Gitea servers
License:        MIT
URL:            https://gitea.com/gitea/tea
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.24
Conflicts:      tea

%description
Tea can be used to manage most entities on one or multiple Gitea
instances and provides local helpers like 'tea pr checkout'.

It tries to make use of context provided by the repository in $PWD
if available. And works best in a upstream/fork workflow, when the
local main branch tracks the upstream repo. It also assumes that
local git state is published on the remote before doing operations.
Configuration lives in $XDG_CONFIG_HOME/tea.

The binary name has been renamed to "gitea", as "tea" has been
already taken.

%package bash-completion
Summary:        Bash Completion for Gitea's tea CLI
BuildRequires:  bash-completion
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for Gitea's tea CLI.

%package zsh-completion
Summary:        Zsh Completion for Gitea's tea CLI
BuildRequires:  zsh
Requires:       %{name} = %{version}
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for Gitea's tea CLI.

%prep
%autosetup -a1

%build
go build \
   -o tea \
   -mod=vendor \
   -buildmode=pie \
   -ldflags "-X main.Version=%{version}"

# building docs
go build \
   -o docs/CLI.md \
   -mod=vendor \
   -buildmode=pie \
   -ldflags "-X main.Version=%{version}"

%install
install -v -m 0755 -D -t %{buildroot}%{_bindir} tea

install -v -m 0644 -D contrib/autocomplete.sh \
    %{buildroot}%{_datadir}/bash-completion/completions/tea

install -v -m 0644 -D contrib/autocomplete.zsh \
    %{buildroot}%{_datadir}/zsh/site-functions/_tea

%files
%license LICENSE
%doc CHANGELOG.md docs/CLI.md CONTRIBUTING.md README.md
%{_bindir}/tea

%files bash-completion
%{_datadir}/bash-completion/completions/tea

%files zsh-completion
%{_datadir}/zsh/site-functions/_tea

%changelog
* Tue Jun 17 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.10.1:
  * 8212d5f Update release ci (#768)
  * d536242 chore(deps): update crazy-max/ghaction-import-gpg action
    to v6 (#736)
  * ffff540 fix(deps): update module github.com/urfave/cli/v3 to
    v3.3.8 (#766)
* Tue Jun 10 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.10.0:
  * fix: support SSH remotes with non-standard ports
  * minor helper fixes
  * Bump Table Dep
  * Login via oauth2 flow
  * Feat: interactive issue edit command
  * Use flakes vs devbox
  * Fix helper panic
  * Add --note-file flag to read release notes from a file
  * Fix/Login Edit Use Editor Env
  * Gitea Actions support
  * Expose --labels option
  * Add git helper
  * Support auto detecting branch for PRs
  * context: move human readable note to stderr
  * Add repos rm/delete command
  * Release Asset Management
  * tea branches list/protect/unprotect
  * Add OTP and scopes to login
  * Initial CLI docs
  * Fix for go tools called from make
  * fix interactive login add
  * issues list can show filtered by owner/org instead of repo too
  * fix: non-standard ssh port URL's repo can't be recognized
  * updated dependencies
- remove newer-dependencies.patch, as upstream updated them
* Thu Apr 24 2025 Richard Rahl <rrahl0@opensuse.org>
- update newer-dependencies.patch, fixing bsc#1241819
* Wed Mar 12 2025 Richard Rahl <rrahl0@opensuse.org>
- update newer-dependencies.patch, fixes bsc#1235367 bsc#1239493 bsc#1234598
* Tue Feb 25 2025 Richard Rahl <rrahl0@opensuse.org>
- adding newer-dependencies.patch, for updating dependencies,
  fixing bsc#1234598
* Thu Aug 22 2024 Richard Rahl <rrahl0@opensuse.org>
- fix build for non x86_64 and aarch64 (CGO_ENABLED=0 was set as default)
* Thu Mar  7 2024 Richard Rahl <rrahl0@proton.me>
- rename binary to tea (actual name) and conflict tea text edidor
* Sat Jul  8 2023 Luciano Santos <luc14n0@opensuse.org>
- Upstream version 0.9.2: Initial openSUSE package.
